@@ -12,6 +12,21 @@ from .PriceModel import Price
 from .ProductModel import Product
 
 
+class Video(BaseModel):
+    video_id: int
+    height: int
+    width: int
+    thumbnail_url: str
+    video_url: str
+    video_state: str
+    
+
+class VariationImage(BaseModel):
+    property_id: int
+    value_id: int
+    value: Optional[str] = None
+    image_id: int
+
 class Inventory(BaseModel):
     products: List[Product]
     price_on_property: List[int]
@@ -20,6 +35,40 @@ class Inventory(BaseModel):
     listing: Optional[Listing]
 
 
+class DraftListing(BaseModel):
+    quantity: int
+    title: str
+    description: str
+    price: float
+    who_made: str = "i_did"
+    when_made: str = "made_to_order"
+    taxonomy_id: int
+    shipping_profile_id: Optional[int]
+    return_policy_id: Optional[int]
+    materials: Optional[List[str]]
+    shop_section_id: Optional[int]
+    processing_min: Optional[int]
+    processing_max: Optional[int]
+    tags: Optional[List[str]]
+    styles: Optional[List[str]]
+    item_weight: Optional[float]
+    item_length: Optional[float]
+    item_width: Optional[float]
+    item_height: Optional[float]
+    item_weight_unit: Optional[str]
+    item_dimensions_unit: Optional[str]
+    is_personalizable: bool
+    personalization_is_required: Optional[bool]
+    personalization_char_count_max: Optional[int]
+    personalization_instructions: Optional[int]
+    production_partner_ids: List[int]
+    image_ids: List[int]
+    is_supply: bool
+    is_customizable: bool
+    should_auto_renew: bool
+    is_taxable: bool
+    type: str = "physical"
+    
 class Listing(BaseModel):
     listing_id: int
     user_id: int
