@@ -1,7 +1,8 @@
 from __future__ import annotations
 from typing import List
 from pydantic import BaseModel
-from . import Offering, PropertyValue
+from .OfferingModel import Offering
+from .PropertyValueModel import PropertyValue
 
 class Product(BaseModel):
     product_id: int
