@@ -1,8 +1,8 @@
 from pydantic import BaseModel
 from typing import List
-from . import (
-    ShippingProfileUpgrade, ShippingProfileDestination
-)
+from .ShippingProfileUpgradeModel import ShippingProfileUpgrade
+from .ShippingProfileDestinationModel import ShippingProfileDestination
+
 
 class ShippingProfile(BaseModel):
     shipping_profile_id: int
